@@ -2,7 +2,7 @@
 
 package HPC::Runner::GnuParallel;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use DateTime;
 use DateTime::Format::Duration;
@@ -11,6 +11,8 @@ use Moose;
 extends 'HPC::Runner';
 extends 'HPC::Runner::MCE';
 
+with 'MooseX::Getopt::Usage';
+
 has 'using_gnuparallel' => (
     is => 'rw',
     isa => 'Bool',
@@ -19,8 +21,11 @@ has 'using_gnuparallel' => (
 );
 
 =head2 infile
+
 disable infile and read directly from the stream
+
 =cut
+
 has '+infile' => (
     required => 0,
 );
@@ -66,9 +71,6 @@ sub go{
 
 Parse the file of commands and send each command off to the queue.
 
-#TODO
-#Merge mce/threads subroutines
-
 =cut
 
 sub parse_file_gnuparallel{
@@ -86,6 +88,7 @@ sub parse_file_gnuparallel{
 
 
 1;
+
 __END__
 
 =encoding utf-8
@@ -96,7 +99,18 @@ HPC::Runner::GnuParallel - Run arbitrary bash commands using GNU parallel. Can b
 
 =head1 SYNOPSIS
 
-  use HPC::Runner::GnuParallel;
+
+  package Main;
+
+  use Moose;
+
+  extends 'HPC::Runner::GnuParallel';
+
+  Main->new_with_options()->go;
+
+  1;
+
+
 
   Run straight as :
 
@@ -106,6 +120,7 @@ HPC::Runner::GnuParallel - Run arbitrary bash commands using GNU parallel. Can b
 
   Or as a part or HPC::Runner::Slurm distro.
 
+
 =head1 DESCRIPTION
 
 HPC::Runner::GnuParallel is a part of a suite of tools to make HPC easy.
